from flask import Flask, jsonify
import requests
from requests.auth import HTTPBasicAuth

""" Config ###
Set via environment variable
FLASK_NMS_URL: Node Media Server API endpoint (e.g. https://tv.ptb.de/api)
FLASK_NMS_URLS: Node Media Server API endpoints as list (e.g. '["https://server1.tv.ptb.de/api","https://server0.tv.ptb.de/api"]')
FLASK_NMS_USER: Node Media Server API user
FLASK_NMS_PASSWORD: Node Media Server API password
"""

app = Flask(__name__)
app.config.from_prefixed_env()

basic_auth = HTTPBasicAuth(app.config["NMS_USER"], app.config["NMS_PASSWORD"])

try:
    nms_urls = app.config["NMS_URLS"]
except KeyError:
    nms_urls = None


@app.get("/<stream_name>")
def get_viewcount(stream_name: str):
    viewers = 0

    if nms_urls:
        responses = []
        for nms_url in nms_urls:
            r = requests.get(
                f"{nms_url}/streams",
                auth=basic_auth,
                proxies={"http": "", "https": ""},
            )

            responses.append(r)

        for r in responses:
            if r.ok:
                data = r.json()

                stream_data = data["live"].get(stream_name)

                if stream_data:
                    viewers += len(stream_data.get("subscribers"))

    else:
        r = requests.get(
            f'{app.config["NMS_URL"]}/streams',
            auth=basic_auth,
            proxies={"http": "", "https": ""},
        )

        if r.ok:
            data = r.json()

            stream_data = data["live"].get(stream_name)

            if stream_data:
                viewers = len(stream_data.get("subscribers"))

    return jsonify(viewers)


@app.route("/health")
def health():
    return "", 204
